@@ -1,6 +1,6 @@
 # Copyright (c) 2008 Infrae. All rights reserved.
 # See also LICENSE.txt
-# $Id: install.py 28748 2008-05-20 09:23:54Z sylvain $
+# $Id: install.py 28983 2008-06-04 10:18:12Z sylvain $
 
 def install(root):
     """Install Captcha Support.
@@ -29,7 +29,9 @@ def uninstall(context):
     """Uninstall Captcha Support.
     """
     sm = context.getSiteManager()
-    sm.unregisterUtility(IKeyManager)
+    utility = sm.queryUtility(IKeyManager)
+    parent = utility.aq_parent
+    parent.manage_delObjects(['IKeyManager'])
     
 def is_installed(context):
     return not (queryUtility(IKeyManager) is None)
